//
//  RTC8564ライブラリ アラームのテスト
//		copyright (c) 2012,2013 T.Nakao    http://www.wsnak.com
//
//  120414 T.Nakao
//  120513
//

#include <Wire.h>
#include <wI2cRtc8564.h>

wI2cRtc8564 rtc;    // RTC-8564ドライバ

char StrBuf[16];
int Count = 30;
byte AlmOn = false;

//
//  初期化
//
void setup(void) {
  byte year, mon, day, wkday;
  byte hur, min, sec;

  Wire.begin();           // I2Cマスタ初期化
  rtc.init();             // RTC初期化

  Serial.begin(19200);    // シリアル通信初期化
  pinMode(13, OUTPUT);

  Serial.println("RTC test");

  // 日時設定
  rtc.setDate(0x12, 4, 0x13, 5);  // 2012/4/13 金
  rtc.setTime(0x23, 0x59, 0x58);    //

  PrintDateTime();      // 日時をシリアル送信

  // 10秒待ち
  delay(10000);
  Serial.println("... after 10s");
  PrintDateTime();      // 日時をシリアル送信

  // アラームセット
  rtc.setAlarm(0x14, 0, 1);   // 14日 00時01分
  rtc.AlmEnable(0, 1, 1, 1);  // 日、時、分 有効

  // アラーム時刻を読み出してシリアル送信
  Serial.println("**** Alarm set ***");
  rtc.readAlarm(&day, &hur, &min);
  sprintf(StrBuf, "day=%02x %02x:%02x", day, hur, min);
  Serial.println(StrBuf);
}


//
//  メインループ
//
void loop(void) {
  byte year, mon, day, wkday;
  byte hur, min, sec;


  if(rtc.checkAlarm()) {
    // アラーム発生
    digitalWrite(13, HIGH);

    if(!AlmOn) {
        AlmOn = true;
        Serial.println("**** Alarm ON ****");
        PrintDateTime();      // 日時をシリアル送信
    }
  }

  delay(100);
  digitalWrite(13, LOW);
  delay(100);

  if(!AlmOn) {
    return;
  }

  if(Count > 0) {
    Count--;
    if(Count == 0) {
      rtc.AlmStop();                // アラーム停止
//      rtc.setAlarm(0x14, 0, 2);   // 14日 00時02分
      Serial.println("**** Alarm OFF ****");
      PrintDateTime();              // 日時をシリアル送信
      Count--;                      // stop
    }
  }

}


//
// 日時を読み出してシリアル送信
//
void PrintDateTime(void) {
  byte year, mon, day, wkday;
  byte hur, min, sec;

  // 日時を読み出し
  rtc.readDate(&year, &mon, &day, &wkday);
  rtc.readTime(&hur, &min, &sec);

  // 日時をシリアル送信
  sprintf(StrBuf, "20%02x/%02x/%02x-%02x", year, mon, day, wkday);
  Serial.println(StrBuf);
  sprintf(StrBuf, "%02x:%02x:%02x", hur, min, sec);
  Serial.println(StrBuf);
}

